xsdata.formats.dataclass package
================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.dataclass.models
   xsdata.formats.dataclass.parsers
   xsdata.formats.dataclass.serializers

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.dataclass.context
   xsdata.formats.dataclass.filters
   xsdata.formats.dataclass.generator
   xsdata.formats.dataclass.utils

Module contents
---------------

.. automodule:: xsdata.formats.dataclass
   :members:
   :undoc-members:
   :show-inheritance:
